@@ -13,7 +13,7 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
-from tempest_lib.exceptions import CommandFailed
+from tempest.lib.exceptions import CommandFailed
 
 from designateclient.functionaltests.base import BaseDesignateTest
 from designateclient.functionaltests.datagen import random_a_recordset_name
@@ -25,7 +25,7 @@ from designateclient.functionaltests.v2.fixtures import ZoneFixture
 class TestRecordset(BaseDesignateTest):
 
     def setUp(self):
-        super(TestRecordset, self).setUp()
+        super().setUp()
         self.ensure_tld_exists('com')
         self.zone = self.useFixture(ZoneFixture(
             name=random_zone_name(),
@@ -36,7 +36,7 @@ class TestRecordset(BaseDesignateTest):
         self.recordset = self.useFixture(RecordsetFixture(
             zone_id=self.zone.id,
             name=name,
-            records='1.2.3.4',
+            record='1.2.3.4',
             description='An a recordset',
             type='A',
             ttl=1234,
@@ -77,7 +77,7 @@ class TestRecordset(BaseDesignateTest):
         rset = self.clients.recordset_set(
             self.zone.id,
             self.recordset.id,
-            records='2.3.4.5',
+            record='2.3.4.5',
             ttl=2345,
             description='Updated description',
         )
@@ -101,9 +101,9 @@ class TestRecordset(BaseDesignateTest):
 class TestRecordsetNegative(BaseDesignateTest):
 
     def test_invalid_option_on_recordset_create(self):
-        cmd = 'recordset create de47d30b-41c5-4e38-b2c5-e0b908e19ec7 ' \
-            'aaa.desig.com. --type A --records 1.2.3.4 ' \
-            '--invalid "not valid"'
+        cmd = ('recordset create de47d30b-41c5-4e38-b2c5-e0b908e19ec7 '
+               'aaa.desig.com. --type A --record 1.2.3.4 '
+               '--invalid "not valid"')
         self.assertRaises(CommandFailed, self.clients.openstack, cmd)
 
     def test_invalid_recordset_command(self):
