@@ -16,14 +16,13 @@
 
 import logging
 
-from cliff import command
-from cliff import lister
-from cliff import show
-import six
+from osc_lib.command import command
 
 from designateclient import utils
+from designateclient.v2.cli import common
 from designateclient.v2.utils import get_all
 
+
 LOG = logging.getLogger(__name__)
 
 
@@ -32,22 +31,25 @@ def _format_tld(tld):
     tld.pop('links', None)
 
 
-class ListTLDsCommand(lister.Lister):
+class ListTLDsCommand(command.Lister):
     """List tlds"""
 
     columns = ['id', 'name', 'description']
 
     def get_parser(self, prog_name):
-        parser = super(ListTLDsCommand, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
-        parser.add_argument('--name', help="TLD NAME")
+        parser.add_argument('--name', help='TLD NAME')
 
-        parser.add_argument('--description', help="TLD Description")
+        parser.add_argument('--description', help='TLD Description')
+
+        common.add_all_common_options(parser)
 
         return parser
 
     def take_action(self, parsed_args):
         client = self.app.client_manager.dns
+        common.set_all_common_headers(client, parsed_args)
 
         data = get_all(client.tlds.list)
 
@@ -55,53 +57,61 @@ class ListTLDsCommand(lister.Lister):
         return cols, (utils.get_item_properties(s, cols) for s in data)
 
 
-class ShowTLDCommand(show.ShowOne):
+class ShowTLDCommand(command.ShowOne):
     """Show tld details"""
 
     def get_parser(self, prog_name):
-        parser = super(ShowTLDCommand, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
-        parser.add_argument('id', help="TLD ID")
+        parser.add_argument('id', help='TLD name or ID')
+
+        common.add_all_common_options(parser)
 
         return parser
 
     def take_action(self, parsed_args):
         client = self.app.client_manager.dns
+        common.set_all_common_headers(client, parsed_args)
         data = client.tlds.get(parsed_args.id)
         _format_tld(data)
-        return six.moves.zip(*sorted(six.iteritems(data)))
+        return zip(*sorted(data.items()))
 
 
-class CreateTLDCommand(show.ShowOne):
+class CreateTLDCommand(command.ShowOne):
     """Create new tld"""
 
     def get_parser(self, prog_name):
-        parser = super(CreateTLDCommand, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
-        parser.add_argument('--name', help="TLD Name", required=True)
-        parser.add_argument('--description', help="Description")
+        parser.add_argument('--name', help='TLD Name', required=True)
+        parser.add_argument('--description', help='Description')
+
+        common.add_all_common_options(parser)
 
         return parser
 
     def take_action(self, parsed_args):
         client = self.app.client_manager.dns
+        common.set_all_common_headers(client, parsed_args)
         data = client.tlds.create(parsed_args.name, parsed_args.description)
         _format_tld(data)
-        return six.moves.zip(*sorted(six.iteritems(data)))
+        return zip(*sorted(data.items()))
 
 
-class SetTLDCommand(show.ShowOne):
+class SetTLDCommand(command.ShowOne):
     """Set tld properties"""
 
     def get_parser(self, prog_name):
-        parser = super(SetTLDCommand, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
-        parser.add_argument('id', help="TLD ID")
-        parser.add_argument('--name', help="TLD Name")
+        parser.add_argument('id', help='TLD name or ID')
+        parser.add_argument('--name', help='TLD Name')
         description_group = parser.add_mutually_exclusive_group()
-        description_group.add_argument('--description', help="Description")
+        description_group.add_argument('--description', help='Description')
         description_group.add_argument('--no-description', action='store_true')
 
+        common.add_all_common_options(parser)
+
         return parser
 
     def take_action(self, parsed_args):
@@ -116,24 +126,28 @@ class SetTLDCommand(show.ShowOne):
             data['description'] = parsed_args.description
 
         client = self.app.client_manager.dns
+        common.set_all_common_headers(client, parsed_args)
 
         data = client.tlds.update(parsed_args.id, data)
         _format_tld(data)
-        return six.moves.zip(*sorted(six.iteritems(data)))
+        return zip(*sorted(data.items()))
 
 
 class DeleteTLDCommand(command.Command):
     """Delete tld"""
 
     def get_parser(self, prog_name):
-        parser = super(DeleteTLDCommand, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
 
-        parser.add_argument('id', help="TLD ID")
+        parser.add_argument('id', help='TLD name or ID')
+
+        common.add_all_common_options(parser)
 
         return parser
 
     def take_action(self, parsed_args):
         client = self.app.client_manager.dns
+        common.set_all_common_headers(client, parsed_args)
         client.tlds.delete(parsed_args.id)
 
         LOG.info('TLD %s was deleted', parsed_args.id)
