@@ -1,12 +1,11 @@
-from __future__ import print_function
 import logging
+import os
 
 from designateclient.v2 import client
 from designateclient import exceptions
-from designateclient import shell
 
-from keystoneclient.auth.identity import generic
-from keystoneclient import session as keystone_session
+from keystoneauth1.identity import generic
+from keystoneauth1 import session as keystone_session
 
 
 logging.basicConfig(level='DEBUG')
@@ -17,10 +16,12 @@ Example script to create or get a domain and add some records to it.
 
 
 auth = generic.Password(
-    auth_url=shell.env('OS_AUTH_URL'),
-    username=shell.env('OS_USERNAME'),
-    password=shell.env('OS_PASSWORD'),
-    tenant_name=shell.env('OS_TENANT_NAME'))
+    auth_url=os.environ.get('OS_AUTH_URL'),
+    username=os.environ.get('OS_USERNAME'),
+    password=os.environ.get('OS_PASSWORD'),
+    project_name=os.environ.get('OS_PROJECT_NAME'),
+    project_domain_id='default',
+    user_domain_id='default')
 
 session = keystone_session.Session(auth=auth)
 
@@ -30,7 +31,7 @@ client = client.Client(session=session)
 try:
     zone = client.zones.create('i.io.', email='i@i.io')
 except exceptions.RemoteError:
-    zone = dict([(z['name'], z) for z in client.zones.list()])['i.io.']
+    zone = {z['name']: z for z in client.zones.list()}['i.io.']
 
 print("Recordset list...")
 for rs in client.recordsets.list(zone['id']):
